@@ -19,6 +19,7 @@
 #' @param merge Logical; in the case that tehre are more than one NetCDF per pollutant,
 #' merge = TRUE will merge them with sum. Default is FALSE.
 #' @param k, Numeric; Value to factorize each pollutant.
+#' @param recursive Logical to search files recursive
 #' @param verbose Logical to print more information
 #' @return RasterStack
 #' @importFrom raster stack raster rotate
@@ -43,73 +44,68 @@
 #'
 #' @export
 #' @examples
-#' \dontrun{
-#' # Not run
+#' \donttest{
 #' # Downloading EDGAR data ####
+#' p <- tempdir()
+#' tot <- paste0(p, "/TOT")
+#' dir.create(tot)
+#'
 #' get_edgar(
 #'   dataset = "v432_VOC_spec",
-#'   destpath = "V50_432_AP/TOT/",
+#'   destpath = tot,
 #'   sector = c("TOTALS"),
 #'   type = "nc",
-#'   year = 2012
+#'   year = 2012,
+#'   ask = FALSE
 #' )
 #'
 #' get_edgar(
 #'   dataset = "v50_AP",
-#'   destpath = "V50_432_AP/TOT",
+#'   destpath = tot,
 #'   sector = c("TOTALS"),
 #'   type = "nc",
-#'   year = 2014
+#'   year = 2014,
+#'   ask = FALSE
 #' )
 #'
-#' get_edgar(
-#'   dataset = "v432_VOC_spec",
-#'   destpath = "V50_432_AP/TRO/",
-#'   sector = c("TRO"),
-#'   type = "nc",
-#'   year = 2012, ask = F
-#' )
-#'
-#' get_edgar(
-#'   dataset = "v50_AP",
-#'   destpath = "V50_432_AP/TRO",
-#'   sector = c("TRO_RES", "TRO_noRES"),
-#'   type = "nc",
-#'   year = 2014
-#' )
+#' nc <- paste0(p, "/nc")
 #'
 #' totals <- list.files(
-#'   path = "V50_432_AP/TOT/",
+#'   path = tot,
 #'   full.names = TRUE,
 #'   pattern = ".zip"
 #' )
-#' lapply(totals, unzip, exdir = "V50_432_AP/TOT//")
 #'
+#' lapply(totals, unzip, exdir = nc)
 #'
-#' tros <- list.files(
-#'   path = "V50_432_AP/TRO",
-#'   full.names = TRUE,
-#'   pattern = ".zip"
-#' )
-#' lapply(tros, unzip, exdir = "V50_432_AP/TRO/")
-#' edgar_chem("V50_432_AP/TOT", "radm")
+#' r <- chem_edgar(path = nc,
+#'                 chem = "radm")
+#' library(raster)
+#' plot(r$E_CO)
+#' r$E_CO[] <- ifelse(r$E_CO[] <= 0, NA, r$E_CO[])
+#' br <- c(1.133594e-10, 0.001105391, 0.002727838, 0.007006367, 0.0146665,
+#' 0.03192566, 0.08026344, 0.5739333, 4.110863, 16.47688, 6.641064e+05)
+#' plot(r$E_CO, col = cptcity::cpt(rev = TRUE), breaks = br)
 #' }
 chem_edgar <- function(path,
                        chem,
                        merge = FALSE,
                        k = rep(1, 34),
+                       recursive = TRUE,
                        verbose = TRUE) {
-  dte <- sysdata$dte
-  emis_opt <- sysdata$emis_opt
+  dte <- sysdata$dte                         # nocov start
+  emis_opt <- sysdata$emis_opt               # to heavy to check cod-cov
 
   if (length(k) < 34) stop("k must have 34 elements")
 
   # no covr, becuase it would take too much time
   ncs <- list.files(
-    path = path, # nocov start
+    path = path,
     full.names = TRUE,
-    pattern = ".nc"
+    pattern = ".nc",
+    recursive = recursive
   )
+
   # just checking units again
   a <- ncdf4::nc_open(ncs[1])
   cat("units: ", a$var[[1]]$units, "\n")
@@ -156,11 +152,11 @@ chem_edgar <- function(path,
 
   if(verbose) cat("Detecting the following files:\n")
 
-  if(verbose) cat(as.data.frame(cbind(lncs)), "\n")
+  if(verbose) print(as.data.frame(cbind(lncs)))
 
   la <- unique(unlist(lapply(lncs, length)))
 
-  if (length(la) > 1 & !merge) stop("There should be 1 NetCDF per pollutantt")
+  if (length(la) > 1 & !merge) stop("There should be 1 NetCDF per pollutant")
 
   fr <- function(x) raster::rotate(raster::raster(x)) * 1000 * 3600 * 1000 * 1000
 
@@ -583,18 +579,20 @@ chem_edgar <- function(path,
     return(CB05)
     # neu_ecb05 ####
   } else if (chem %in% c("neu_ecb05", "neu_cb05")) {
+    cb05 <- sysdata$edgar_cb05
+
     # emis_opt$ecb05_opt2[1]
     E_ACET <- 0 * bp$voc9
 
     # emis_opt$ecb05_opt2[2]
-    E_PAR <- 1.00 * bp$voc3  / dte[dte$GEIA_id == "voc3", ]$g_mol +
-             4.00 * bp$voc4  / dte[dte$GEIA_id == "voc4", ]$g_mol +
-             5.00 * bp$voc5  / dte[dte$GEIA_id == "voc5", ]$g_mol +
-             5.86 * bp$voc6  / dte[dte$GEIA_id == "voc6", ]$g_mol +
-             1.00 * bp$voc9  / dte[dte$GEIA_id == "voc9", ]$g_mol +
-             1.00 * bp$voc13 / dte[dte$GEIA_id == "voc13", ]$g_mol +
-             1.00 * bp$voc18 / dte[dte$GEIA_id == "voc18", ]$g_mol +
-             1.00 * bp$voc19 / dte[dte$GEIA_id == "voc19", ]$g_mol
+    E_PAR <- cb05[cb05$GEIA_id == "voc3", ]$M * bp$voc3  / cb05[cb05$GEIA_id == "voc3", ]$g_mol +
+             cb05[cb05$GEIA_id == "voc4", ]$M * bp$voc4  / cb05[cb05$GEIA_id == "voc4", ]$g_mol +
+             cb05[cb05$GEIA_id == "voc5", ]$M * bp$voc5  / cb05[cb05$GEIA_id == "voc5", ]$g_mol +
+             cb05[cb05$GEIA_id == "voc6", ]$M * bp$voc6  / cb05[cb05$GEIA_id == "voc6", ]$g_mol +
+             cb05[cb05$GEIA_id == "voc9", ]$M * bp$voc9  / cb05[cb05$GEIA_id == "voc9", ]$g_mol +
+             cb05[cb05$GEIA_id == "voc13",]$M * bp$voc13 / cb05[cb05$GEIA_id == "voc13",]$g_mol +
+             cb05[cb05$GEIA_id == "voc18",]$M * bp$voc18 / cb05[cb05$GEIA_id == "voc18",]$g_mol +
+             cb05[cb05$GEIA_id == "voc19",]$M * bp$voc19 / cb05[cb05$GEIA_id == "voc19",]$g_mol
 
     # emis_opt$ecb05_opt2[3]
     E_ALK3 <- bp$voc9 * 0
@@ -606,18 +604,18 @@ chem_edgar <- function(path,
     E_ALK5 <- bp$voc9 * 0
 
     # emis_opt$ecb05_opt2[6]
-    E_TOL <- bp$voc14 / dte[dte$GEIA_id == "voc14", ]$g_mol
+    E_TOL <- bp$voc14 / cb05[cb05$group == "E_TOL", ]$g_mol
 
     # emis_opt$ecb05_opt2[7]
-    E_XYL <- bp$voc15 / dte[dte$GEIA_id == "voc15", ]$g_mol +
-             bp$voc16 / dte[dte$GEIA_id == "voc16", ]$g_mol +
-             bp$voc17 / dte[dte$GEIA_id == "voc17", ]$g_mol
+    E_XYL <- bp$voc15 / cb05[cb05$GEIA_id == "voc15", ]$g_mol +
+             bp$voc16 / cb05[cb05$GEIA_id == "voc16", ]$g_mol +
+             bp$voc17 / cb05[cb05$GEIA_id == "voc17", ]$g_mol
 
     # emis_opt$ecb05_opt2[8]
     E_BALD <- bp$voc13 * 0
 
     # emis_opt$ecb05_opt2[9]
-    E_ALD2 <- bp$voc22 / dte[dte$GEIA_id == "voc22", ]$g_mol
+    E_ALD2 <- bp$voc22 / cb05[cb05$group == "E_ALD2", ]$g_mol
 
     # emis_opt$ecb05_opt2[10]
     E_CCOOH <- bp$voc22 * 0
@@ -629,16 +627,16 @@ chem_edgar <- function(path,
     E_CRES <- 0 * bp$voc18
 
     # emis_opt$ecb05_opt2[13]
-    E_ETH <- bp$voc7 / dte[dte$GEIA_id == "voc7", ]$g_mol
+    E_ETH <- bp$voc7 / cb05[cb05$group == "E_ETH", ]$g_mol
 
     # emis_opt$ecb05_opt2[14]
-    E_ETHA <- bp$voc2 / dte[dte$GEIA_id == "voc2", ]$g_mol
+    E_ETHA <- bp$voc2 / cb05[cb05$group == "E_ETHA", ]$g_mol
 
     # emis_opt$ecb05_opt2[15]
     E_GLY <- bp$voc7 * 0
 
     # emis_opt$ecb05_opt2[16]
-    E_FORM <- bp$voc21 / dte[dte$GEIA_id == "voc21", ]$g_mol
+    E_FORM <- bp$voc21 / cb05[cb05$group == "E_FORM", ]$g_mol
 
     # emis_opt$ecb05_opt2[17]
     E_HCOOH <- bp$voc21 * 0
@@ -647,7 +645,7 @@ chem_edgar <- function(path,
     E_IPROD <- bp$voc21 * 0
 
     # emis_opt$ecb05_opt2[19]
-    E_ISOP <- bp$voc10 / dte[dte$GEIA_id == "voc10", ]$g_mol
+    E_ISOP <- bp$voc10 / cb05[cb05$group == "E_ISOP", ]$g_mol
 
     # emis_opt$ecb05_opt2[20]
     E_MACR <- bp$voc10 * 0
@@ -656,13 +654,13 @@ chem_edgar <- function(path,
     E_MEK <- bp$voc10 * 0
 
     # emis_opt$ecb05_opt2[22]
-    E_MEOH <- 0.80 * bp$voc1 / dte[dte$GEIA_id == "voc1", ]$g_mol
+    E_MEOH <- cb05[cb05$group == "E_MEOH", ]$M * bp$voc1 / cb05[cb05$group == "E_MEOH", ]$g_mol
 
     # emis_opt$ecb05_opt2[23]
     E_MEO2 <- bp$voc10 * 0
 
     # emis_opt$ecb05_opt2[24]
-    E_ETOH <- 0.20 * bp$voc1 / dte[dte$GEIA_id == "voc1", ]$g_mol
+    E_ETOH <- cb05[cb05$group == "E_ETOH", ]$M * bp$voc1 / cb05[cb05$group == "E_ETOH", ]$g_mol
 
     # emis_opt$ecb05_opt2[25]
     E_MGLY <- bp$nmvoc * 0
@@ -675,16 +673,16 @@ chem_edgar <- function(path,
     # Chlorinated hydrocarbons	CH3Cl
 
     # emis_opt$ecb05_opt2[28]
-    E_NO <- bp$nox * 0.9 / (14 + 16)
+    E_NO <- bp$nox * cb05[cb05$group == "E_NO", ]$M / (14 + 16)
 
     # emis_opt$ecb05_opt2[29]
-    E_NO2 <- bp$nox * 0.1 / (14 + 16 * 2)
+    E_NO2 <- bp$nox * cb05[cb05$group == "E_NO2", ]$M / (14 + 16 * 2)
 
     # emis_opt$ecb05_opt2[30]
-    E_IOLE <- bp$voc12 / dte[dte$GEIA_id == "voc12", ]$g_mol * 0.75
+    E_IOLE <- cb05[cb05$group == "E_IOLE", ]$M * bp$voc12 / cb05[cb05$group == "E_IOLE", ]$g_mol
 
     # emis_opt$ecb05_opt2[31]
-    E_OLE <- bp$voc8 / dte[dte$GEIA_id == "voc8", ]$g_mol
+    E_OLE <- bp$voc8 / cb05[cb05$group == "E_OLE", ]$g_mol
 
     # emis_opt$ecb05_opt2[32]
     E_PHEN <- bp$voc8 * 0
@@ -693,7 +691,7 @@ chem_edgar <- function(path,
     E_PROD2 <- bp$voc8 * 0
 
     # emis_opt$ecb05_opt2[34]
-    E_ALDX <- bp$voc12 / dte[dte$GEIA_id == "voc12", ]$g_mol * 0.25
+    E_ALDX <- cb05[cb05$group == "E_ALDX", ]$M * bp$voc12 * bp$voc12 / cb05[cb05$group == "E_ALDX", ]$g_mol
 
     # emis_opt$ecb05_opt2[35]
     E_SO2 <- bp$so2 / (64 + 16 * 2)
@@ -702,49 +700,49 @@ chem_edgar <- function(path,
     E_PSULF <- bp$pm2.5 * 0.27 / 3600
 
     # emis_opt$ecb05_opt2[37]
-    E_TERP <- bp$voc11 / dte[dte$GEIA_id == "voc11", ]$g_mol
+    E_TERP <- bp$voc11 / cb05[cb05$group == "E_TERP", ]$g_mol
 
     # emis_opt$ecb05_opt2[38]
-    E_PM25I <- bp$pm2.5 * 0.0 / 3600 # not read by mechanism
+    E_PM25I <- bp$pm2.5 * 0.0 # not read by mechanism
 
     # emis_opt$ecb05_opt2[39]
     E_PM25J <- bp$pm2.5 * (0.8 + 0.2) / 3600
 
     # emis_opt$ecb05_opt2[40]
-    E_ECI <- bp$bc * 0.0 / 3600 # not read by mechanism
+    E_ECI <- bp$bc * 0.0  # not read by mechanism
 
     # emis_opt$ecb05_opt2[41]
     E_ECJ <- bp$bc * (0.8 + 0.2) / 3600
 
     # emis_opt$ecb05_opt2[42]
-    E_ORGI <- bp$oc * 0.0 / 3600 # not read by mechanism
+    E_ORGI <- bp$oc * 0.0 # not read by mechanism
 
     # emis_opt$ecb05_opt2[43]
     E_ORGJ <- bp$oc * (0.8 + 0.2) / 3600
 
     # emis_opt$ecb05_opt2[44]
-    E_SO4I <- bp$pm2.5 * 0.0 / 3600 # not read by mechanism
+    E_SO4I <- bp$pm2.5 * 0.0 # not read by mechanism
 
     # emis_opt$ecb05_opt2[45]
     E_SO4J <- bp$pm2.5 * (0.0623 + 0.0077) / 3600
 
     # emis_opt$ecb05_opt2[46]
-    E_NO3I <- bp$pm2.5 * 0.0 / 3600 # not read by mechanism
+    E_NO3I <- bp$pm2.5 * 0.0 # not read by mechanism
 
     # emis_opt$ecb05_opt2[47]
     E_NO3J <- bp$pm2.5 * (0.01053 + 0.00247) / 3600
 
     # emis_opt$ecb05_opt2[48]
-    E_SO4C <- bp$pm2.5 * 0 / 3600
+    E_SO4C <- bp$pm2.5 * 0
 
     # emis_opt$ecb05_opt2[49]
-    E_NO3C <- bp$pm2.5 * 0 / 3600
+    E_NO3C <- bp$pm2.5 * 0
 
     # emis_opt$ecb05_opt2[50]
-    E_ORGC <- bp$pm2.5 * 0 / 3600
+    E_ORGC <- bp$pm2.5 * 0
 
     # emis_opt$ecb05_opt2[51]
-    E_ECC <- bp$pm2.5 * 0 / 3600
+    E_ECC <- bp$pm2.5 * 0
 
     # emis_opt$ecb05_opt2[52]
     E_PM10 <- (bp$pm10 - bp$pm2.5) * 1 / 3600
@@ -767,7 +765,7 @@ chem_edgar <- function(path,
     names(CB05) <- emis_opt$ecb05_opt2
     cat("units of gases: mol/km2/h\n")
     cat("units of aerosols: ug/m2/s\n")
-    return(CB05) # nocov end
+    return(CB05)
   } else if (chem == "utfpr_cbmz") {
     # emis_opt$ecbmz_mosaic[1]
     E_ISO <- bp$voc10 / dte[dte$GEIA_id == "voc10", ]$g_mol +
@@ -897,5 +895,5 @@ chem_edgar <- function(path,
     return(CBMZ_MOSAIC)
   } else {
     stop("other mechanisms not implemented")
-  }
+  }                                               # nocov end
 }
